hy-language-server
===

[Hy](https://github.com/hylang/hy) Language Server built using [pygls](https://github.com/openlawlibrary/pygls) and [Jedhy](https://github.com/ekaschalk/jedhy).

## Supported Features

Note: Currently, these features are available only for Hy's built-in core functions.

- `textDocument/completion`
- `textDocument/hover`

## Installation

```sh
$ pip install hy-language-server
```

## license

MIT
